==> core-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/ValidationError.java <==
package software.amazon.awscdk.core;

/**
 * An error returned during the validation phase.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:04:46.930Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ValidationError extends software.amazon.jsii.JsiiSerializable {
    /**
     * The error message.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getMessage();

    /**
     * The construct which emitted the error.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.Construct getSource();

    /**
     * @return a {@link Builder} of {@link ValidationError}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ValidationError}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.String message;
        private software.amazon.awscdk.core.Construct source;

        /**
         * Sets the value of Message
         * @param message The error message.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder message(java.lang.String message) {
            this.message = message;
            return this;
        }

        /**
         * Sets the value of Source
         * @param source The construct which emitted the error.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder source(software.amazon.awscdk.core.Construct source) {
            this.source = source;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ValidationError}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public ValidationError build() {
            return new Jsii$Proxy(message, source);
        }

    }

    /**
     * An implementation for {@link ValidationError}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ValidationError {
        private final java.lang.String message;
        private final software.amazon.awscdk.core.Construct source;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.message = this.jsiiGet("message", java.lang.String.class);
            this.source = this.jsiiGet("source", software.amazon.awscdk.core.Construct.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String message, software.amazon.awscdk.core.Construct source) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.message = java.util.Objects.requireNonNull(message, "message is required");
            this.source = java.util.Objects.requireNonNull(source, "source is required");
        }

        @Override
        public java.lang.String getMessage() {
            return this.message;
        }

        @Override
        public software.amazon.awscdk.core.Construct getSource() {
            return this.source;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("message", om.valueToTree(this.getMessage()));
            obj.set("source", om.valueToTree(this.getSource()));
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ValidationError.Jsii$Proxy that = (ValidationError.Jsii$Proxy) o;

            if (!message.equals(that.message)) return false;
            return this.source.equals(that.source);
        }

        @Override
        public int hashCode() {
            int result = this.message.hashCode();
            result = 31 * result + (this.source.hashCode());
            return result;
        }

    }
}

==> core-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/ValidationError.java <==
package software.amazon.awscdk.core;

/**
 * An error returned during the validation phase.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:44:35.481Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ValidationError extends software.amazon.jsii.JsiiSerializable {

    /**
     * The error message.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getMessage();

    /**
     * The construct which emitted the error.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.Construct getSource();

    /**
     * @return a {@link Builder} of {@link ValidationError}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ValidationError}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String message;
        private software.amazon.awscdk.core.Construct source;

        /**
         * Sets the value of Message
         * @param message The error message. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder message(java.lang.String message) {
            this.message = message;
            return this;
        }

        /**
         * Sets the value of Source
         * @param source The construct which emitted the error. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder source(software.amazon.awscdk.core.Construct source) {
            this.source = source;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ValidationError}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public ValidationError build() {
            return new Jsii$Proxy(message, source);
        }
    }

    /**
     * An implementation for {@link ValidationError}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ValidationError {
        private final java.lang.String message;
        private final software.amazon.awscdk.core.Construct source;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.message = this.jsiiGet("message", java.lang.String.class);
            this.source = this.jsiiGet("source", software.amazon.awscdk.core.Construct.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String message, software.amazon.awscdk.core.Construct source) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.message = java.util.Objects.requireNonNull(message, "message is required");
            this.source = java.util.Objects.requireNonNull(source, "source is required");
        }

        @Override
        public java.lang.String getMessage() {
            return this.message;
        }

        @Override
        public software.amazon.awscdk.core.Construct getSource() {
            return this.source;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("message", om.valueToTree(this.getMessage()));
            obj.set("source", om.valueToTree(this.getSource()));
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ValidationError.Jsii$Proxy that = (ValidationError.Jsii$Proxy) o;

            if (!message.equals(that.message)) return false;
            return this.source.equals(that.source);
        }

        @Override
        public int hashCode() {
            int result = this.message.hashCode();
            result = 31 * result + (this.source.hashCode());
            return result;
        }
    }
}
